@@ -21,7 +21,7 @@ def load_curses_colors_decor() -> Tuple[dict, dict]:
 
     Parameters:
         None
-    Returns: 
+    Returns:
         color (dict): Curses color references
         decor (dict): Curses decoration/style references
     """
@@ -30,18 +30,18 @@ def load_curses_colors_decor() -> Tuple[dict, dict]:
 
     # Defining colors [foreground/font, background]
     color_definition = {
-        'default':      [curses.COLOR_WHITE, 0],    # FIXME: Rename to "normal" to match decor
-        'red':          [curses.COLOR_RED, 0],
-        'green':        [curses.COLOR_GREEN, 0],
-        'blue':         [curses.COLOR_BLUE, 0],
-        'yellow':       [curses.COLOR_YELLOW, 0],
-        'orange':       [209, 0],
-        'cyan':         [curses.COLOR_CYAN, 0],
-        'magenta':      [curses.COLOR_MAGENTA, 0],
-        'grey-dark':    [240, 0],
-        'grey-light':   [248, 0],
-        'black-white':  [curses.COLOR_BLACK, curses.COLOR_WHITE],
-        'white-red':    [curses.COLOR_WHITE, curses.COLOR_RED]
+        'default': [curses.COLOR_WHITE, 0],  # FIXME: Rename to "normal" to match decor
+        'red': [curses.COLOR_RED, 0],
+        'green': [curses.COLOR_GREEN, 0],
+        'blue': [curses.COLOR_BLUE, 0],
+        'yellow': [curses.COLOR_YELLOW, 0],
+        'orange': [209, 0],
+        'cyan': [curses.COLOR_CYAN, 0],
+        'magenta': [curses.COLOR_MAGENTA, 0],
+        'grey-dark': [240, 0],
+        'grey-light': [248, 0],
+        'black-white': [curses.COLOR_BLACK, curses.COLOR_WHITE],
+        'white-red': [curses.COLOR_WHITE, curses.COLOR_RED]
     }
 
     # If terminal does not support colors, reset everything to white
@@ -59,18 +59,19 @@ def load_curses_colors_decor() -> Tuple[dict, dict]:
         color[key] = curses.color_pair(index + 1)
 
     # Defining font decorations
-    decoration_definition ={
-        'normal' : curses.A_NORMAL,         # Normal display (no highlight)
-        'standout': curses.A_STANDOUT,      # Best highlighting mode of the terminal
-        'underline': curses.A_UNDERLINE,    # Underlining
-        'reverse': curses.A_REVERSE,        # Reverse video
-        'blink': curses.A_BLINK,            # Blinking
-        'dim': curses.A_DIM,                # Half bright
-        'bold': curses.A_BOLD,              # Extra bright or bold
-        'protect': curses.A_PROTECT,        # Protected mode
-        'invisible': curses.A_INVIS,        # Invisible or blank mode
-        'alt-char': curses.A_ALTCHARSET,    # Alternate character set
-        'char': curses.A_CHARTEXT           # Bit-mask to extract a character
+    decoration_definition = {
+        'normal': curses.A_NORMAL,  # Normal display (no highlight)
+        'standout': curses.A_STANDOUT,  # Best highlighting mode of the terminal
+        'underline': curses.A_UNDERLINE,  # Underlining
+        'reverse': curses.A_REVERSE,  # Reverse video
+        'blink': curses.A_BLINK,  # Blinking
+        'dim': curses.A_DIM,  # Half bright
+        'bold': curses.A_BOLD,  # Extra bright or bold
+        'protect': curses.A_PROTECT,  # Protected mode
+        'invisible': curses.A_INVIS,  # Invisible or blank mode
+        'alt-char': curses.A_ALTCHARSET,  # Alternate character set
+        'char':
+            curses.A_CHARTEXT  # Bit-mask to extract a character
     }
 
     # Initiating curses color and saving for quick reference
@@ -89,19 +90,19 @@ def load_keys() -> dict:
 
     Parameters:
         None
-    Returns: 
+    Returns:
         KEYS (dict): Dictionary of references to curses keys
     """
     KEYS = {
-        "ENTER":  (curses.KEY_ENTER, ord('\n'), ord('\r')),
-        "SPACE":  (32, ord(' ')),
-        "UP":     (curses.KEY_UP, ord('k')),
-        "DOWN":   (curses.KEY_DOWN, ord('j')),
-        "RIGHT":  (curses.KEY_RIGHT, ord('l')),
-        "LEFT":   (curses.KEY_LEFT, ord('h')),
-        "PAUSE":  (ord('p'), ord('P')),
+        "ENTER": (curses.KEY_ENTER, ord('\n'), ord('\r')),
+        "SPACE": (32, ord(' ')),
+        "UP": (curses.KEY_UP, ord('k')),
+        "DOWN": (curses.KEY_DOWN, ord('j')),
+        "RIGHT": (curses.KEY_RIGHT, ord('l')),
+        "LEFT": (curses.KEY_LEFT, ord('h')),
+        "PAUSE": (ord('p'), ord('P')),
         "RESUME": (ord('r'), ord('R')),
-        "QUIT":   (27 , ord('q'), ord('Q'))
+        "QUIT": (27, ord('q'), ord('Q'))
     }
     return KEYS
 
@@ -113,40 +114,40 @@ def load_software_name_version() -> str:
 
     Parameters:
         None
-    Returns: 
+    Returns:
         (str): Software name and version
     """
     software_name = "exam-terminal"
-    software_version = "0.2.5"  # Updated with bumpversion
+    software_version = "0.2.7"  # Updated with bumpversion
     return software_name + ' v' + software_version
 
 
-def center_x(display_width:int, line:str) -> int:
+def center_x(display_width: int, line: str) -> int:
     """
     Find the horizontal center position of the given text line
 
     Parameters:
         display_width (int) : The character width of the screen/space/display
         line (int)          : Line of text
-    Returns: 
+    Returns:
         (int): Horizontal character number
     """
     return display_width // 2 - len(line) // 2
 
 
-def center_y(display_height:int) -> int:
+def center_y(display_height: int) -> int:
     """
     Find the vertical center position of given screen/space/display
 
     Parameters:
         display_width (int) : The character height of the screen/space/display
-    Returns: 
+    Returns:
         (int): Vertical character number
     """
     return display_height // 2
 
 
-def truncate_text(text:str, length_limit:int) -> str:
+def truncate_text(text: str, length_limit: int) -> str:
     """
     Truncating/shortening of text given a length limit.
     Will add "..." to truncated text.
@@ -154,7 +155,7 @@ def truncate_text(text:str, length_limit:int) -> str:
     Parameters:
         text (str)         : The character height of the screen/space/display
         length_limit (int) : Length limit of the text
-    Returns: 
+    Returns:
         truncated_text (str): The truncated line of text
     """
     truncated_text = text
@@ -164,7 +165,7 @@ def truncate_text(text:str, length_limit:int) -> str:
     return truncated_text
 
 
-def get_message_box_size(term_height:int, term_width:int, message_lines:list) -> Tuple[int, int, int, int]:
+def get_message_box_size(term_height: int, term_width: int, message_lines: list) -> Tuple[int, int, int, int]:
     """
     Given a message box list with each item being a message box line/row,
     this method find the right size and position of the message box for
@@ -174,7 +175,7 @@ def get_message_box_size(term_height:int, term_width:int, message_lines:list) ->
         term_height (int)    : Number of rows/lines in terminal
         term_width (int)     : Number of columns in terminal
         message_lines (list) : Lines of text in each list item
-    Returns: 
+    Returns:
         box_height (int) : Height of message box (rows/lines)
         box_width (int)  : Width of message box (columns)
         box_y (int)      : Vertical position of box in terminal
@@ -197,14 +198,14 @@ def get_progress_bar(exam_progress: float, bar_char_width=60, bar_char_full='|',
         bar_char_width (int)  : Total width of progress bar, columns of text
         bar_char_full (str)   : Symbol for filled
         bar_char_empty (str)  : Symbol for empty
-    Returns: 
+    Returns:
         (str) : Progress bar as text
     """
     # TODO: Different colors for different parts of the progress bar somehow
 
     progress_str = []
     for i in range(bar_char_width):
-        
+
         if i <= exam_progress * bar_char_width:
             progress_str.append(bar_char_full)
         else:
@@ -214,14 +215,14 @@ def get_progress_bar(exam_progress: float, bar_char_width=60, bar_char_full='|',
     return progress_str
 
 
-def draw_screen_border(scr, color:list) -> None:
+def draw_screen_border(scr, color: list) -> None:
     """
     Draw a border around entire terminal screen with specified color
 
     Parameters:
         scr (obj)   : Handle for curses terminal screen handle
         color (list): Foreground and background color (ie. [250, 0])
-    Returns: 
+    Returns:
         None
     """
     scr.attron(color)
@@ -229,7 +230,7 @@ def draw_screen_border(scr, color:list) -> None:
     scr.attroff(color)
 
 
-def draw_horizontal_seperator(scr, y:int, color:list) -> None:
+def draw_horizontal_seperator(scr, y: int, color: list) -> None:
     """
     Draw a horizontal line accross the terminal screen at specified height
     and with specified color
@@ -238,7 +239,7 @@ def draw_horizontal_seperator(scr, y:int, color:list) -> None:
         scr (obj)   : Handle for curses terminal screen handle
         y (int)     : The line/row number from top of the screen
         color (list): Foreground and background color (ie. [250, 0])
-    Returns: 
+    Returns:
         None
     """
     scr.attron(color)
@@ -252,7 +253,7 @@ def draw_horizontal_seperator(scr, y:int, color:list) -> None:
             scr.addstr(y, x + 1, '-', color)
 
 
-def draw_vertical_seperator(scr, x:int, color:list) -> None:
+def draw_vertical_seperator(scr, x: int, color: list) -> None:
     """
     Draw a vertical line accross the terminal screen at specified character
     column and with specified color
@@ -261,19 +262,19 @@ def draw_vertical_seperator(scr, x:int, color:list) -> None:
         scr (obj)   : Handle for curses terminal screen handle
         x (int)     : The column number from left of the screen
         color (list): Foreground and background color (ie. [250, 0])
-    Returns: 
+    Returns:
         None
     """
     # TODO: Currently unused but may come in handy
 
 
-def load_examfile_contents_from_local_file(local_file_path:str) -> Dict:
+def load_examfile_contents_from_local_file(local_file_path: str) -> Dict:
     """
     Loading a local file exam contents
 
     Parameters:
         local_file_path (str) : Path to a local file to be loaded
-    Returns: 
+    Returns:
         file_contents (Dict) : The contents of the file
     """
     # TODO: Check if right file type (.yml or .yaml)
@@ -288,14 +289,14 @@ def load_examfile_contents_from_local_file(local_file_path:str) -> Dict:
     return file_contents
 
 
-def load_examfile_contents_from_url(remote_file_url:url, allow_redirects:bool=True) -> Dict:
+def load_examfile_contents_from_url(remote_file_url: url, allow_redirects: bool = True) -> Dict:
     """
     Loading a remote exam file contents over HTTP
 
     Parameters:
         remote_file_url (url)  : Remote URL location of file to be loaded
         allow_redirects (bool) : If True allow redirects to another URL (defulat True)
-    Returns: 
+    Returns:
         file_contents (Dict) : The contents of the file
     """
     # Getting name of file from URL
@@ -306,7 +307,8 @@ def load_examfile_contents_from_url(remote_file_url:url, allow_redirects:bool=Tr
     remote_file_ext = Path(remote_file_url).suffix
     file_ext_accepted = ['.yml', '.yaml']
     if not remote_file_ext in file_ext_accepted:
-        logger.debug(f'Remote file requested "{remote_filename}"" is not one of the accepted file types: {file_ext_accepted}')
+        logger.debug(
+            f'Remote file requested "{remote_filename}"" is not one of the accepted file types: {file_ext_accepted}')
         return {}
 
     # Get request headers
@@ -322,7 +324,9 @@ def load_examfile_contents_from_url(remote_file_url:url, allow_redirects:bool=Tr
     content_length = int(header['Content-length']) / 1000000
     logger.debug(f'Requested file content length: {content_length:.5f} MB)')
     if content_length > 1.0:
-        logger.debug(f'The requested remote file "{remote_filename}" is {content_length:.2f} MB and larger than 1.0 MB limit, will not download')
+        logger.debug(
+            f'The requested remote file "{remote_filename}" is {content_length:.2f} MB and larger than 1.0 MB limit, will not download'
+        )
         return {}
 
     # Check if content is text or yaml based
@@ -332,7 +336,9 @@ def load_examfile_contents_from_url(remote_file_url:url, allow_redirects:bool=Tr
     if not content_type:
         return {}
     elif not any(ext in content_type for ext in content_types_accepted):
-        logger.debug(f'The content type "{content_type}" of the requested file "{remote_filename}" is not one of the following: {content_types_accepted}')
+        logger.debug(
+            f'The content type "{content_type}" of the requested file "{remote_filename}" is not one of the following: {content_types_accepted}'
+        )
         return {}
 
     # Downloading the file content
@@ -350,23 +356,24 @@ def load_examfile_contents_from_url(remote_file_url:url, allow_redirects:bool=Tr
             logger.debug(f'Failed loading requested file. Exception: {e}')
             return {}
     else:
-        logger.debug(f"Failed to get remote file '{remote_file_url}'. HTTP request error code {remote_request.status_code}")
+        logger.debug(
+            f"Failed to get remote file '{remote_file_url}'. HTTP request error code {remote_request.status_code}")
         return {}
 
     return file_contents
 
 
-def to_seconds(time_quantity:int, time_unit_text:str) -> int:
+def to_seconds(time_quantity: int, time_unit_text: str) -> int:
     """
     Get the number of seconds form the time quantity and time unit type.
-    Examples: 
+    Examples:
         - 45 min -> 2700 seconds
         - 2 days -> 432000 seconds
 
     Parameters:
         time_quantity (int)  : Number of time units
         time_unit_text (str) : Type of time units (ie. seconds, minutes, hours, etc)
-    Returns: 
+    Returns:
         seconds (int) : Number of seconds
     """
     if not time_quantity:
@@ -388,4 +395,4 @@ def to_seconds(time_quantity:int, time_unit_text:str) -> int:
         blue_moon = 41  # months
         return time_quantity * blue_moon * 2.628e+6
 
-    return 0
\ No newline at end of file
+    return 0
